@@ -1,7 +1,7 @@
 package Encode::Locale;
 
 use strict;
-our $VERSION = "0.04";
+our $VERSION = "1.00";
 
 use base 'Exporter';
 our @EXPORT_OK = qw(
@@ -215,6 +215,13 @@ environment variable named $uni_key.
 The returned value will have the characters that can't be decoded replaced by
 "\x{FFFD}", the Unicode replacement character.
 
+There is no interface to request alternative CHECK behavior as for
+decode_argv().  If you need that you need to call encode/decode yourself.
+For example:
+
+    my $key = Encode::encode(locale => $uni_key, Encode::FB_CROAK);
+    my $uni_value = Encode::decode(locale => $ENV{$key}, Encode::FB_CROAK);
+
 =item reinit( )
 
 =item reinit( $encoding )
@@ -285,10 +292,15 @@ On Mac OS X the file system encoding is always UTF-8 while the locale
 can otherwise be set up as normal for POSIX systems.
 
 File names on Mac OS X will at the OS-level be converted to
-NFD form.  A file created by passing a NFC-filename will come
-in NFD from from readdir().  See L<Unicode::Normalize> for details
+NFD-form.  A file created by passing a NFC-filename will come
+in NFD-form from readdir().  See L<Unicode::Normalize> for details
 of NFD/NFC.
 
+Actually, Apple does not follow the Unicode NFD standard since not all
+character ranges are decomposed.  The claim is that this avoids problems with
+round trip conversions from old Mac text encodings.  See L<Encode::UTF8Mac> for
+details.
+
 =head2 POSIX (Linux and other Unixes)
 
 File systems might vary in what encoding is to be used for
